.TH EKG 1 "11 listopada 2002" 
.SH NAZWA
ekg \- Eksperymentalny Klient Gadu-Gadu
.SH SKŁADNIA
.B ekg [
.BI opcje
.B ]
.B [
.BI komendy
.B ]

.SH OPIS
.B ekg
jest eksperymentalnym klientem Gadu-Gadu.

.SH OPCJE
.TP
.BI \-h\ [\-\-help]
Wyświetla listę możliwych opcji.
.TP
.BI \-u\ username\ [\-\-user\ username]
Pozwala na uruchomienie ekg z innym ,,profilem użytkownika''.
Standardowo konfiguracja ekg znajduje sie w katalogu ~/.gg/ (chyba, że
zdefiniowana jest zmienna środowiskowa $CONFIG_DIR - wtedy w ~/$CONFIG_DIR/gg/).
Ta opcja pozwala na stworzenie struktury podkatalogów z oddzielnymi
konfiguracjami.
.TP
.BI \-t\ theme\ [\-\-theme\ theme]
Ładuje motyw z podanego pliku.
.TP
.BI \-c\ plik\ [\-\-control-pipe\ plik]
Tworzy nazwany potok (ang. named pipe) umożliwiający sterowanie klientem.
.TP
.BI \-n\ [\-\-no-auto]
Nie łącz się automagicznie. Po uruchomieniu nie łączy się automatycznie 
z serwerami gg. 
.TP
.BI \-N\ [\-\-no-global-config]
Nie czytaj globalnego pliku konfiguracyjnego (np. /etc/ekg.conf) po
wczytaniu pliku konfiguracyjnego użytkownika.
.TP
.BI \-a\ [\-\-away[=opis]]
Po połączeniu zmienia stan na ,,zajęty''.
.TP
.BI \-b\ [\-\-back[=opis]]
Po połączeniu zmienia stan na ,,dostępny''.
.TP 
.BI \-i\ [\-\-invisible[=opis]]
Po połączeniu zmienia stan na ,,niewidoczny''.
.TP
.BI \-p\ [\-\-private]
Po połączeniu włącza tryb ,,tylko dla przyjaciół''.
.TP
.BI \-v\ [\-\-version]
Wyświetla wersję klienta i biblioteki libgadu.
.TP
.BI \-f\ nazwa\ [\-\-frontend\ nazwa]
Wybiera podany interfejs użytkownika.
