.TH EKL2 1 "2 Marca 2003" 
.SH NAZWA
ekl2 \- Podgląd historii Eksperymentalnego Klienta Gadu-Gadu.
.SH SKŁADNIA
.B ekl2 [
.BI OPCJE
.B ] [
.BI ŹRÓDŁO
.B ]
.SH OPIS
.B ekl2
Jest to aplikacja umożliwiająca podgląd historii rozmów, tworzonej przez
Eksperymentalnego Klienta Gadu-Gadu.
.SH OPCJE
.TP
.BI \-d\ +format\ \-\-date\ +format\ 
Ustala format wyświetlanej daty (zobacz date(1)).
.TP
.BI \-\-location\ 
Ustala miejsce przechowywania plików dziennika (domyślnie ~/.gg/history).
.TP
.BI \-h\ \-\-help\ 
Wyświetla pomoc.
.TP
.BI \-L\ \-\-List\ 
Pokazuje listę dostępnych logow. (z katalogu ~/.gg/history).
.TP
.BI \-l\ \-\-sessions\ [+num]\ [+ods]
Pokazuje listę sesji w podanym logu.
Nieobowiązkowy parametr
.BI num\ 
to numer sesji, która ma zostać wyświetlona, a 
.BI ods\ 
to odstęp między rozmowami, w minutach (domyślnie: 60)
.TP
.BI \-n\ \-\-nocolor\ 
Bez kolorków.
.BI \-sh\ \-\-short\ 
simplified form.
.TP
.BI \-v\ \-\-version\ 
Prints script version.
.TP
.BI ŹRÓDŁO\ 
numer gg, nick lub nazwa pliku z logami.
.SH "PATRZ TEŻ"
.BR ekg (1).
