.TH EKGLOGS 1 "7 września 2003"
.SH NAZWA
ekglogs \- program do wypisywania historii rozmów EKG
.SH SKŁADNIA
.B ekglogs [
.BI opcje
.B ]
<
.B ~/.gg/history

.SH OPIS
.B ekglogs
pobiera logi ekg ze standardowego wejścia i wypisuje je w ładnej formie na
standardowe wyjście.
	
.SH OPCJE
.TP
.BI \-t
nie wyświetlaj w ogóle czasu
.TP
.BI \-d
nie wyświetlaj zmiany dni
.TP
.BI \-x
zawsze wyświetlaj ksywkę
.TP
.BI \-v
nigdy nie wyświetlaj ksywki 
(domyślnie: wyświetlaj jeśli nie podano opcji `u' ani `n')
.TP
.BI \-r
wyświetlaj czas odebrania w wiadomościach przychodzących
.TP
.BI \-R
j/w i wyrównaj wiadomości wychodzące
.TP
.BI \-s
wyświetlaj sekundy
.TP
.BI \-S
wyświetlaj sekundy przy czasie odebrania
.TP
.BI \-C
wyświetlaj dwukropek między godziną a minutą
.TP
.BI \-b
nie wyświetlaj błędnych linijek (zaczynają się od !!!)
.TP
.BI \-a
nie wyświetlaj zmian statusu
.TP
.BI \-c
wyświetlaj kolorki
.TP
.BI \-h
wyświetl krótką pomoc
.TP
.BI \-u\ UIN
pokazuj tylko wiadomości od/do \fIUIN\fR
.TP
.BI \-n\ NICK
pokazuj tylko wiadomości od/do \fINICK\fRa
.PP
Opcji nie trzeba poprzedzać `-', można je łączyć lub nie.
.PP
Opcje `u' oraz `n' powinny być na końcu i nie powinny występować razem

.SH AUTOR
Robert Goliasz <rgoliasz@poczta.onet.pl>
.SH "PATRZ TAKŻE"
.BR ekg (1)
